/*-
 * ============LICENSE_START=======================================================
 * SDC
 * ================================================================================
 * Copyright (C) 2019 AT&T Intellectual Property. All rights reserved.
 * Modifications Copyright (c) 2019 Samsung
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.openecomp.sdc.be.dao.utils;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import java.util.Collections;
import java.util.Map;

import org.junit.Assert;
import org.junit.Test;

public class DaoUtilsTest {

    private static final Map<String, String> TEST_OBJECT = Collections.singletonMap("key", "value");

    private static final String JSON = "{\"key\":\"value\"}";
    private static final Class<Map> CLAZZ = Map.class;

    @Test
    public void testConvertToJson() {
        String result = DaoUtils.convertToJson(TEST_OBJECT);
        Assert.assertEquals(JSON, result);
    }

    @Test(expected = RuntimeException.class)
    public void testConvertToJsonNullObject() {
        DaoUtils.convertToJson(null);
    }

    @Test
    public void testConvertFromJson() {
        Map result = DaoUtils.convertFromJson(CLAZZ, JSON);
        assertEquals(TEST_OBJECT, result);
    }

    @Test(expected = RuntimeException.class)
    public void testConvertFromNullClassToJson() {
        DaoUtils.convertFromJson(null, JSON);
    }
}
